ServiceId

Type Alias ServiceId 

pub type ServiceId = u32;
SessionId, ServiceId, and SessionTarget are provided by hopr-types and re-exported here via hopr-utils, so they match the published hopr-api session types.

  • SessionId is a type alias for HoprPseudonym (a constant application tag is used for all sessions instead of dynamically allocating tags).
  • ServiceId identifies a service local to the Exit node (e.g. Cover Traffic).
  • SessionTarget describes where data received over the session is forwarded. Identifies a node-local service target.

These are specialized SessionTargets that are local to the Exit node and have different purposes, such as Cover Traffic.

These targets cannot be sealed from the Entry node.