SessionId

Type Alias SessionId 

pub type SessionId = SimplePseudonym;
SessionId, ServiceId, and SessionTarget are provided by hopr-types and re-exported here via hopr-utils, so they match the published hopr-api session types.

  • SessionId is a type alias for HoprPseudonym (a constant application tag is used for all sessions instead of dynamically allocating tags).
  • ServiceId identifies a service local to the Exit node (e.g. Cover Traffic).
  • SessionTarget describes where data received over the session is forwarded. Identity of a HOPR Session.

Aliased Type

pub struct SessionId(/* private fields */);