pub type HoprStartProtocol = StartProtocol<SessionId, SessionTarget, ByteCapabilities>;Expand description
Start protocol instantiation for HOPR.
Aliased Type
pub enum HoprStartProtocol {
StartSession(StartInitiation<SessionTarget, ByteCapabilities>),
SessionEstablished(StartEstablished<SessionId>),
SessionError(StartErrorType),
KeepAlive(KeepAliveMessage<SessionId>),
}Variants
StartSession(StartInitiation<SessionTarget, ByteCapabilities>)
Request to initiate a new session.
SessionEstablished(StartEstablished<SessionId>)
Confirmation that a new session has been established by the counterparty.
SessionError(StartErrorType)
Counterparty could not establish a new session due to an error.
KeepAlive(KeepAliveMessage<SessionId>)
A ping message to keep the session alive.